@@ -390,6 +390,7 @@ class DataAPIClient(BaseAPIClient):
         personal_data_removed=None,
         *,
         user_research_opted_in=None,
+        active=None,
     ):
         warnings.warn(
             "The output of 'find_users' is paginated. Use 'find_users_iter' instead.",
@@ -410,6 +411,8 @@ class DataAPIClient(BaseAPIClient):
             params['personal_data_removed'] = personal_data_removed
         if user_research_opted_in is not None:
             params['user_research_opted_in'] = user_research_opted_in
+        if active is not None:
+            params['active'] = active
         return self._get("/users", params=params)
 
     find_users_iter = make_iter_method('find_users', 'users')
@@ -1039,6 +1042,10 @@ class DataAPIClient(BaseAPIClient):
         return self._get(
             "/agreements/{}".format(framework_agreement_id))
 
+    def get_supplier_framework_agreement(self, framework_slug):
+        return self._get(
+            "/agreements/{}".format(framework_slug))
+
     def create_framework_agreement(self, supplier_id, framework_slug, user=None):
         return self._post_with_updated_by(
             "/agreements",
@@ -1057,6 +1064,13 @@ class DataAPIClient(BaseAPIClient):
             user=user,
         )
 
+    def update_framework_agreement_undo_countersign(self, framework_agreement_id, user=None):
+        return self._post_with_updated_by(
+            "/agreements/{}/undo-countersign".format(framework_agreement_id),
+            data={},
+            user=user,
+        )
+
     def sign_framework_agreement(self, framework_agreement_id, user, signed_agreement_details=None):
         data = {"agreement": {"signedAgreementDetails": signed_agreement_details}} if signed_agreement_details else {}
         return self._post_with_updated_by(
